@@ -1,3 +1,4 @@
+#include <config.h>
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -122,7 +123,7 @@ read_line (FILE *stream, GString *str)
     {
       int c;
       
-#ifndef G_OS_WIN32
+#ifdef HAVE_FLOCKFILE
       c = getc_unlocked (stream);
 #else
       c = getc (stream);
@@ -385,7 +386,7 @@ parse_chars (gchar     *text,
 
 /* While not as cool as c-mode, this will do as a quick attempt at highlighting */
 static void
-fontify ()
+fontify (void)
 {
   GtkTextIter start_iter, next_iter, tmp_iter;
   gint state;
