@@ -29,8 +29,8 @@ extern "C" {
 #include <gtk/gtkselection.h>
 
 #define GTK_TYPE_CLIPBOARD            (gtk_clipboard_get_type ())
-#define GTK_CLIPBOARD(obj)            (GTK_CHECK_CAST ((obj), GTK_TYPE_CLIPBOARD, GtkClipboard))
-#define GTK_IS_CLIPBOARD(obj)         (GTK_CHECK_TYPE ((obj), GTK_TYPE_CLIPBOARD))
+#define GTK_CLIPBOARD(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_CLIPBOARD, GtkClipboard))
+#define GTK_IS_CLIPBOARD(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_CLIPBOARD))
 
 typedef void (* GtkClipboardReceivedFunc)        (GtkClipboard     *clipboard,
 					          GtkSelectionData *selection_data,
@@ -38,6 +38,13 @@ typedef void (* GtkClipboardReceivedFunc)        (GtkClipboard     *clipboard,
 typedef void (* GtkClipboardTextReceivedFunc)    (GtkClipboard     *clipboard,
 					          const gchar      *text,
 					          gpointer          data);
+typedef void (* GtkClipboardImageReceivedFunc)   (GtkClipboard     *clipboard,
+						  GdkPixbuf        *pixbuf,
+						  gpointer          data);
+typedef void (* GtkClipboardTargetsReceivedFunc) (GtkClipboard     *clipboard,
+					          GdkAtom          *atoms,
+						  gint              n_atoms,
+					          gpointer          data);
 
 /* Should these functions have GtkClipboard *clipboard as the first argument?
  * right now for ClearFunc, you may have trouble determining _which_ clipboard
@@ -78,6 +85,8 @@ void     gtk_clipboard_clear          (GtkClipboard          *clipboard);
 void     gtk_clipboard_set_text       (GtkClipboard          *clipboard,
 				       const gchar           *text,
 				       gint                   len);
+void     gtk_clipboard_set_image      (GtkClipboard          *clipboard,
+				       GdkPixbuf             *pixbuf);
 
 void gtk_clipboard_request_contents (GtkClipboard                    *clipboard,
 				     GdkAtom                          target,
@@ -86,13 +95,38 @@ void gtk_clipboard_request_contents (GtkClipboard                    *clipboard,
 void gtk_clipboard_request_text     (GtkClipboard                    *clipboard,
 				     GtkClipboardTextReceivedFunc     callback,
 				     gpointer                         user_data);
+void gtk_clipboard_request_image    (GtkClipboard                    *clipboard,
+				     GtkClipboardImageReceivedFunc    callback,
+				     gpointer                         user_data);
+void gtk_clipboard_request_targets  (GtkClipboard                    *clipboard,
+				     GtkClipboardTargetsReceivedFunc  callback,
+				     gpointer                         user_data);
 
-GtkSelectionData *gtk_clipboard_wait_for_contents (GtkClipboard *clipboard,
-						   GdkAtom       target);
-gchar *           gtk_clipboard_wait_for_text     (GtkClipboard *clipboard);
+GtkSelectionData *gtk_clipboard_wait_for_contents (GtkClipboard  *clipboard,
+						   GdkAtom        target);
+gchar *           gtk_clipboard_wait_for_text     (GtkClipboard  *clipboard);
+GdkPixbuf *       gtk_clipboard_wait_for_image    (GtkClipboard  *clipboard);
+gboolean          gtk_clipboard_wait_for_targets  (GtkClipboard  *clipboard,
+						   GdkAtom      **targets,
+						   gint          *n_targets);
 
-gboolean gtk_clipboard_wait_is_text_available   (GtkClipboard         *clipboard);
+gboolean gtk_clipboard_wait_is_text_available   (GtkClipboard *clipboard);
+gboolean gtk_clipboard_wait_is_image_available  (GtkClipboard *clipboard);
+gboolean gtk_clipboard_wait_is_target_available (GtkClipboard *clipboard,
+						 GdkAtom       target);
 
+
+void gtk_clipboard_set_can_store (GtkClipboard         *clipboard,
+				  const GtkTargetEntry *targets,
+				  gint                  n_targets);
+
+void gtk_clipboard_store         (GtkClipboard   *clipboard);
+  
+/* private */
+void     _gtk_clipboard_handle_event    (GdkEventOwnerChange *event);
+
+void     _gtk_clipboard_store_all       (void);
+  
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
